@@ -34,23 +34,23 @@ class thermocouple:
 
     def read(self):
 
-        time.sleep(250/1000)
+        time.sleep(20/1000)
         self.cs.write(0)
-        time.sleep(50/1000)
+        time.sleep(20/1000)
         
         bit_array = ""
-        for i in range(16):
+        for i in range(16-3):
             self.sclk.write(0)
-            time.sleep(50/1000)
+            time.sleep(21/1000)
             
             bit_array = bit_array + str( self.miso.read()*1 )
             
             self.sclk.write(1)
-            time.sleep(50/1000)
+            time.sleep(21/1000)
         
         self.cs.write(1)
-        time.sleep(50/1000)
+        time.sleep(10/1000)
         
-        return int(bit_array[1:-3],2)/4
+        return int(bit_array[1:],2)/4
 
 
